################# A Model of QE, Reserve Demand, and the Money Multiplier #################
################# Authors: Ellen Ryan and Karl Whelan #################

##############File overview and pre-requisites 

### Must run File 1 first
### File produces illustrative charts for Section 4 of the paper


###Set-up


library(ggplot2)


### CHANGE THIS!
setwd("C:/Users/ryanell/Desktop/PhD/Macro money/R/Charts/B. Illustrative model")
getwd()




###################### Run model with 1 period of QE and multiple periods ##############################################


res_mult_80 <- (1+0.02*0.8)/(1-0.8+0.02*0.8)

res_mult_99 <- (1+0.02*0.99)/(1-0.99+0.02*0.99)


eq_res_80<- 100/res_mult_80

eq_res_99<- 100/res_mult_99

purchases_one <-  c(rep(0,5),rep(10,1),rep(0,174))

purchases_continued <-  c(rep(0,5),rep(10,25),rep(0,150))

purchases_one_2 <-  c(rep(0,5),rep(5,1),rep(0,174))




mm_model_core_new(iteration = 1, cb = purchases_one, beta_h = 0.80, beta_l = 0.80, num_banks = 100, 
                  sh_low_beta = 0, sh_seller = 0.8, seller_pp = 0.6,
                  res_start = eq_res_80, dep_start = 100, curr_res = rep(5,length(purchases_one)), 
                  non_bank_sh = 0.75, repay = 0.02, 
                  print_detail = FALSE)


stats_test80_qe1<- key_stats



mm_model_core_new(iteration = 1, cb = purchases_one, beta_h = 0.99, beta_l = 0.99, num_banks = 100, 
                  sh_low_beta = 0, sh_seller = 0.8, seller_pp = 0.6,
                  res_start = eq_res_99, dep_start = 100, curr_res = rep(5,length(purchases_one)), 
                  non_bank_sh = 0.75, repay = 0.02,
                  print_detail = FALSE)


stats_test99_qe1 <- key_stats




mm_model_core_new(iteration = 1, cb = purchases_continued, beta_h = 0.80, beta_l = 0.80, num_banks = 100, 
                  sh_low_beta = 0, sh_seller = 0.8, seller_pp = 0.6,
                  res_start = eq_res_80, dep_start = 100, curr_res = rep(5,length(purchases_continued)), 
                  non_bank_sh = 0.75, repay = 0.02, 
                  print_detail = FALSE)


stats_test80_qec<- key_stats



mm_model_core_new(iteration = 1, cb = purchases_continued, beta_h = 0.99, beta_l = 0.99, num_banks = 100, 
                  sh_low_beta = 0, sh_seller = 0.8, seller_pp = 0.6,
                  res_start = eq_res_99, dep_start = 100, curr_res = rep(5,length(purchases_continued)), 
                  non_bank_sh = 0.75, repay = 0.02,
                  print_detail = FALSE)


stats_test99_qec <- key_stats

## Possible to back repayment rate out of pre-purchase aggregates? YES!

x<- (stats_test99_qec$total_reserves[1] - (1-0.99)*(stats_test99_qec$total_deposits[1]))/(0.99*(stats_test99_qec$total_deposits[1]-stats_test99_qec$total_reserves[1]))


###################### Figure 4 ##############################################


ggplot() + geom_line(data = stats_test99_qe1,  aes(x = period, y = model_money_mult), size = 1, colour="black") + 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) 

  
#+ ggtitle("Money multiplier one period of QE and Beta = 0.99") + theme(legend.position = "none")

#colour="royalblue3"

dev.copy(pdf,'qe1_99_mult_bw.pdf')

dev.off()


ggplot() + geom_line(data =  stats_test80_qe1,  aes(x = period, y = model_money_mult)) + theme_bw() + ggtitle("Money multiplier one period of QE andBeta = 0.8")



#Equilibrium reached when excess reserves equal Repayments
ggplot() + geom_line(data = stats_test99_qe1[which(stats_test99_qe1$period > 1),],  aes(x = period, y = bank_push, linetype = "New deposits from excess reserves"), size = 1, color = "black") + 
  geom_line(data = stats_test99_qe1[which(stats_test99_qe1$period > 1),],  aes(x = period, y = total_loans*0.02, linetype = "Repayments"), size = 1, color = "black") + 
  xlab ("Time period")  +  ylab ("")  +
#  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + 
  theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) + guides(linetype = guide_legend(nrow = 2))


dev.copy(pdf,'qe1_99_eq_bw.pdf')

dev.off()


###################### Figure 5 ##############################################


ggplot() + geom_line(data = stats_test99_qec,  aes(x = period, y = model_money_mult), size = 1, color = "black") + 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) 

#colour="royalblue3"
#+ ggtitle("Money multiplier one period of QE and Beta = 0.99") + theme(legend.position = "none")

dev.copy(pdf,'qec_99_mylt_bw.pdf')

dev.off()


#Equilibrium reached when excess reserves equal Repayments
ggplot() + geom_line(data = stats_test99_qec[which(stats_test99_qec$period > 1),],  aes(x = period, y = bank_push, linetype = "New deposits from excess reserves"), color = "black", size = 1) + 
  geom_line(data = stats_test99_qec[which(stats_test99_qec$period > 1),],  aes(x = period, y = total_loans*0.02, linetype = "Repayments"), color = "black", size = 1) + 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))+ guides(linetype = guide_legend(nrow = 2))


dev.copy(pdf,'qec_99_eq_bw.pdf')

dev.off()




#What is happening to currency and reserves? 

ggplot(stats_test99_qec[which(stats_test99_qec$period <100),])  + 
  geom_area(aes(x = period, y = total_reserves + currency, fill = "Currency")) + 
  geom_area(aes(x = period, y = total_reserves, group = iteration, fill = "Reserves"))+ 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank())  + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))


# dev.copy(pdf,'qec_99_curr_bw.pdf')
# 
# dev.off()




###################### Run model with exog. currency ######################




mm_model_core_new(iteration = 1, cb = purchases_one_2, beta_h = 0.99, beta_l = 0.99, num_banks = 100, 
                  sh_low_beta = 0, sh_seller = 0.8, seller_pp = 0.6,
                  res_start = eq_res_99, dep_start = 100, curr_res = rep(0,length(purchases_one_2)), 
                  non_bank_sh = 0.75, repay = 0.02,
                  print_detail = FALSE)


stats_test99_qe1_ex <- key_stats

stats_test99_qe1_ex$curr_ex <- rep(5*eq_res_99,length(purchases_one_2)+1)

stats_test99_qe1_ex$mult2 <- (stats_test99_qe1_ex$total_deposits+stats_test99_qe1_ex$curr_ex)/ (stats_test99_qe1_ex$total_reserves+stats_test99_qe1_ex$curr_ex)
  

##Figure 5 RHS (LHS is in file 3)

ggplot() + geom_line(data = stats_test99_qe1_ex,  aes(x = period, y = mult2), size = 1, colour="black") + 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) 

dev.copy(pdf,'qe1_99_mult_ex_bw.pdf')

dev.off()

#Equilibrium reached when excess reserves equal Repayments
ggplot() + geom_line(data = stats_test99_qe1_ex[which(stats_test99_qe1_ex$period > 1),],  aes(x = period, y = bank_push, linetype = "New deposits from excess reserves"),color = "black", size = 1) + 
  geom_line(data = stats_test99_qe1_ex[which(stats_test99_qe1_ex$period > 1),],  aes(x = period, y = total_loans*0.02, linetype = "Aggregate repayments"),color = "black", size = 1) + 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))

dev.copy(pdf,'qe1_99_eq_ex_bw.pdf')

dev.off()

  

ggplot() + geom_line(data = stats_test99_qe1_ex,  aes(x = period, y = total_deposits/total_reserves), size = 1, colour="black") + 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) 

dev.copy(pdf,'qe1_99_ex_dep_res_bw.pdf')

dev.off()

ggplot() + geom_line(data = stats_test99_qe1_ex,  aes(x = period, y = curr_ex/total_reserves), size = 1, colour="black") + 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) 


dev.copy(pdf,'qe1_99_ex_curr_res_bw.pdf')

dev.off()
  
  