################# A Model of QE, Reserve Demand, and the Money Multiplier #################
################# Authors: Ellen Ryan and Karl Whelan #################

##############File overview and pre-requisites 

### No pre-requisites
### File produces imports main FRED data file and produces descriptive charts
### This data is needed for file 3.2 which runs US-calibrated models


## Set-up
install.packages("writexl")

install.packages("ggplot2")

install.packages("xts")

install.packages("zoo")

install.packages("lubridate")

#install.packages("dplyr")

library(readxl)
#library(writexl)
library(ggplot2)
#library(rJava)
#library(xlsx)
#library(xlsReadWrite)
library(xts)
#library(zoo)
library(lubridate)

library(dplyr)
library(tidyr)

setwd("C:/Users/ryanell/Desktop/Macro money/R")
getwd()

################# Import data and create new variables #########################


#Import from excel (PROB NEED TO CHANGE AROUND FILE LOCATIONS)
us_mon_agg <- read_excel("Data/us_mon_aggs_long.xlsx", 
                              sheet = "r_input")

  
us_mon_agg$date_m<-as.Date(us_mon_agg$date)


#Add required variables to us monetary aggs data 

us_mon_agg$m2_fix<- us_mon_agg$M2 - us_mon_agg$CURRENCY - us_mon_agg$`retail money funds`

us_mon_agg$money_mult <- (us_mon_agg$CURRENCY + us_mon_agg$m2_fix)/(us_mon_agg$CURRENCY + us_mon_agg$RESERVES)


us_mon_agg$cd <- us_mon_agg$CURRENCY/us_mon_agg$m2_fix

us_mon_agg$cr <- us_mon_agg$CURRENCY/us_mon_agg$RESERVES

us_mon_agg$base_ch <- (us_mon_agg$CURRENCY+us_mon_agg$RESERVES) - (lag(us_mon_agg$CURRENCY,1)+lag(us_mon_agg$RESERVES,1))


#us_mon_agg$res_ch[1]<-0
us_mon_agg$base_ch[1]<-0


us_mon_agg$period <- seq(1:nrow(us_mon_agg))

                   
#For dates https://www.newyorkfed.org/markets/programs-archive/large-scale-asset-purchases


lsap_dates <- data.frame(start=as.Date(c("2008-12-01", "2010-11-01","2012-09-01","2017-10-01")), 
                              end=as.Date(c( "2010-03-01", "2011-06-01", "2014-10-01","2019-10-01")),
                              prog=c("QE1", "QE2", "QE3", "Normalisation"))




################################################################# Charts #################################################################

###### Figure 3 
ggplot() + geom_line(data = us_mon_agg, aes(x = date_m, y = RESERVES/1000), color = "black", size = 1) + 
       xlab ("")  +  ylab ("")  + theme_bw() + scale_y_continuous(breaks=seq(0,3.5,.5), limits = c(0,3.5)) + 
      scale_x_date(breaks = as.Date(c("2004-01-01","2006-01-01","2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2004","2006","2008", "2010", "2012", "2014", "2016", "2018", "2020")) + 
      theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
      geom_text(data=lsap_dates, mapping=aes(x=end, y= 2, label=prog), size=5, angle=90, vjust=-0.4, hjust=0, color = "black") +
       geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=0, ymax=3.5), fill="grey", alpha=0.2) 


#ggsave("Charts/A. Data/res.png")


dev.copy(pdf,'Charts/A. Data/res_bw.pdf')

dev.off()



#MONEY MULTIPLIER CHART IN PAPER
ggplot() + geom_line(data = us_mon_agg, aes(x = date_m, y = money_mult), color = "black", size = 1) + 
  xlab ("")  +  ylab ("")  + theme_bw() + scale_y_continuous(breaks=seq(0,10,2), limits = c(0,10)) + 
  scale_x_date(breaks = as.Date(c("2004-01-01","2006-01-01","2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2004","2006","2008", "2010", "2012", "2014", "2016", "2018", "2020")) + 
  theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20))+
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 7, label=prog), size=5, angle=90, vjust=-0.4, hjust=0, color = "black") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=0, ymax=10), fill="grey", alpha=0.2) 



#ggsave("Charts/A. Data/us_mult.png")



dev.copy(pdf,'Charts/A. Data/us_mult_bw.pdf')

dev.off()


#### Figure 5 LHS

ggplot() + geom_area(data = us_mon_agg, aes(x = date_m, y = (CURRENCY + RESERVES)/1000, fill = "Currency")) + 
  geom_area(data = us_mon_agg, aes(x = date_m, y = RESERVES/1000, fill = "Reserves")) + 
  xlab ("")  +  ylab ("")  + theme_bw() + scale_y_continuous(breaks=seq(0,5,1), limits = c(0,5)) + 
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) + 
#  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + 
  scale_fill_manual(values = c("grey","black")) +
  theme(legend.text=element_text(size=20)) +
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + 
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 3.2, label=prog), size=5, angle=90, vjust=-0.4, hjust=0, color = "black") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=0, ymax=5), fill="grey", alpha=0.2) 


dev.copy(pdf,'mon_base_us_bw.pdf')

dev.off()


#Currency to deposits
ggplot() + geom_line(data = us_mon_agg, aes(x = date_m, y = cd), size = 1) + 
  xlab ("")  +  ylab ("")  + theme_bw() + scale_y_continuous(breaks=seq(0.1,0.15,.01), limits = c(0.1,0.15)) + 
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) + 
  theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 0.14, label=prog), size=6, angle=90, vjust=-0.4, hjust=0, color = "black") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=0.1, ymax=0.15), fill="grey", alpha=0.2) +ggtitle("Currency/Deposits")


#Currency to deposits
ggplot() + geom_line(data = us_mon_agg, aes(x = date_m, y = cd), size = 1) + 
  xlab ("")  +  ylab ("")  + theme_bw() + scale_y_continuous(breaks=seq(0.1,0.15,.01), limits = c(0.1,0.15)) + 
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) + 
  theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 0.14, label=prog), size=6, angle=90, vjust=-0.4, hjust=0, color = "black") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=0.1, ymax=0.15), fill="grey", alpha=0.2) +ggtitle("Currency/Deposits")



#Currency to reserves
ggplot() + geom_line(data = us_mon_agg, aes(x = date_m, y = CURRENCY/RESERVES), size = 1) +ylim(0,1)

