################# A Model of QE, Reserve Demand, and the Money Multiplier #################
################# Authors: Ellen Ryan and Karl Whelan #################

##############File overview and pre-requisites 

### Must run File 1 and 3.1 first to have model and required data loaded
### File produces US-calibrated output for Section 5 of the paper
### To produce output faster reduce num_it input variables (this runs the model fewer times but results 
### are largely unchanged)

##In simple terms calibration works as follows:


### Take first values from US mon agg data to produce banking system's aggregate
## starting balance sheet (e.g. i_dep_start= us_mon_agg2$m2_fix[1] )

## Use monthly changes in US reserves as central bank purchases variable (i_cb = us_mon_agg2$base_ch)

## Use the actual month on month currency to reserve ratio from the US (i_curr_res = us_mon_agg2$cr)





#######Set-up


library(ggplot2)
library(dplyr)

### CHANGE THIS
setwd("C:/Users/ryanell/Desktop/Macro money/R/Charts/C. US calib")
getwd()




############################### Drop pre-QE months for analysis
us_mon_agg2 <- us_mon_agg[seq(56,nrow(us_mon_agg)),]

us_mon_agg2$period <- seq(1:nrow(us_mon_agg2))

us_mon_agg2$date[1]


########################### Run with "pre-QE" Beta (0.99) #####################################

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.99, i_beta_l = 0.99, i_num_banks = 100, 
                  i_sh_low_beta = 0, i_sh_seller = 0.8, i_seller_pp = 0.6,
                  i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], i_curr_res = us_mon_agg2$cr, 
                  i_non_bank_sh = 0.9, i_repay = 0.01, 
                  i_print_detail = FALSE)


us_stats_b<- key_stats


us_stats_b<-key_stats[which(us_stats_b$period > 0),]

#Add dates to model output

us_stats_b$date_m<-c(us_mon_agg2$date_m)


## These create cross-iteration summary statistics (e.g. median multiplier across iterations)
us_stats_b_sum<- us_stats_b %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
             top_dep = quantile(total_deposits, prob = 0.99))

us_stats_b_sum$period <- seq(1,nrow(us_mon_agg2))

####Figure 6 #####
ggplot() + geom_line(data = us_mon_agg2[which(us_mon_agg2$period <15),], aes(x = date_m, y = (m2_fix+CURRENCY)/(RESERVES+CURRENCY), linetype = "Data: US"), size = 2.1, color = "black") +
  geom_line(data=us_stats_b_sum[which(us_stats_b_sum$period <15),], aes(x = date_m, y = med_mult, linetype = "Model: Pre-QE beta"), size = 0.8, color = "black") +
  ylab("") + xlab("") + scale_x_date(date_labels = "%b/%y") + theme_bw()+ 
#  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + 
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + 
  theme(legend.text=element_text(size=20))+
  theme(legend.key.width = unit(3,"cm")) 


dev.copy(pdf,'us_baseline_beta_bw.pdf')

dev.off()



########################### Run with range of new betas #####################################

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.95, 
                             i_beta_l =0.1,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr,
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_print_detail = FALSE)


us_panel_95<- bank_panel
us_stats_95<-key_stats
us_stats_95$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_stats_95_sum<- us_stats_95 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
             top_dep = quantile(total_deposits, prob = 0.99))
             
         

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.9, 
                             i_beta_l =0.1,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr,
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_print_detail = FALSE)


us_panel_90<- bank_panel
us_stats_90<-key_stats
us_stats_90$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_stats_90_sum<- us_stats_90 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
             top_dep = quantile(total_deposits, prob = 0.99))
             
         

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                             i_beta_l =0.1,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr,
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_print_detail = FALSE)


us_panel_85<- bank_panel
us_stats_85<-key_stats
us_stats_85$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_stats_85_sum<- us_stats_85 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
             top_dep = quantile(total_deposits, prob = 0.99))
             
        


mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.8, 
                             i_beta_l =0.1,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr,
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_print_detail = FALSE)


us_panel_80<- bank_panel
us_stats_80<-key_stats
us_stats_80$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_stats_80_sum<- us_stats_80 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
             top_dep = quantile(total_deposits, prob = 0.99))
             
         

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.75, 
                             i_beta_l =0.1,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr,
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_print_detail = FALSE)


us_panel_75<- bank_panel
us_stats_75<-key_stats
us_stats_75$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_stats_75_sum<- us_stats_75 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
             top_dep = quantile(total_deposits, prob = 0.99))
    


mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.7, 
                             i_beta_l =0.1,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr,
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_print_detail = FALSE)


us_panel_70<- bank_panel
us_stats_70<-key_stats
us_stats_70$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)



us_stats_70_sum<- us_stats_70 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
             top_dep = quantile(total_deposits, prob = 0.99))

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.65, 
                             i_beta_l =0.1,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr,
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_print_detail = FALSE)


us_panel_65<- bank_panel
us_stats_65<-key_stats
us_stats_65$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_stats_65_sum<- us_stats_65 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
             top_dep = quantile(total_deposits, prob = 0.99))
             

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.6, 
                             i_beta_l =0.1,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr,
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_print_detail = FALSE)


us_panel_60<- bank_panel
us_stats_60<-key_stats
us_stats_60$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_stats_60_sum<- us_stats_60 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
             top_dep = quantile(total_deposits, prob = 0.99))
             

############ Figure 7 ############ 

##Black and white - differentiate by line style

ggplot() + 
  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = med_dep/1000, linetype = "Beta = 0.85"), size = 1.2)  +
  geom_line(data = us_stats_75_sum, aes(x = date_m, y = med_dep/1000, linetype = "Beta = 0.75"), size = 1.2) +
  geom_line(data = us_stats_80_sum,  aes(x = date_m, y = med_dep/1000, linetype = "Beta = 0.8"), size = 1.2)  +
  geom_line(data = us_stats_70_sum, aes(x = date_m, y = med_dep/1000, linetype = "Beta = 0.7"), size = 1.2) +
  geom_line(data = us_stats_90_sum, aes(x = date_m, y = med_dep/1000, linetype = "Beta = 0.90"), size = 1.2) +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = m2_fix/1000), color = "black", size = 3) +
  theme_bw() + ylab("USDbn") + xlab("") + 
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 17.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "black") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=0, ymax=25), fill="grey", alpha=0.2) + 
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  scale_linetype_manual(values = c("solid","dashed","twodash","dotted","dotdash")) +
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) +
  guides(linetype = guide_legend(nrow = 3))+
  theme(legend.key.width = unit(3,"cm")) 

dev.copy(pdf,'many_betas_deps_bw.pdf')

dev.off()

ggplot() + 
  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = med_mult, linetype = "Beta = 0.85"), size = 1.2)  +
  geom_line(data = us_stats_75_sum, aes(x = date_m, y = med_mult, linetype = "Beta = 0.75"), size = 1.2) +
  geom_line(data = us_stats_80_sum,  aes(x = date_m, y = med_mult, linetype = "Beta = 0.8"), size = 1.2)  +
  geom_line(data = us_stats_70_sum, aes(x = date_m, y = med_mult, linetype = "Beta = 0.7"), size = 1.2) +
  geom_line(data = us_stats_90_sum, aes(x = date_m, y = med_mult, linetype = "Beta = 0.90"), size = 1.2) +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = (m2_fix+CURRENCY)/(RESERVES+CURRENCY)), color = "black", size = 3) +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "black") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  scale_linetype_manual(values = c("solid","dashed","twodash","dotted","dotdash")) +
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) +
  guides(linetype = guide_legend(nrow = 3))+
  theme(legend.key.width = unit(3,"cm")) 

dev.copy(pdf,'many_betas_bw.pdf')

dev.off()


##Black and white - differentiate by point shape

ggplot() + 
#  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = med_dep/1000, linetype = "Beta = 0.85"), color = "black", size = 0.8)  +
#  geom_line(data = us_stats_80_sum,  aes(x = date_m, y = med_dep/1000, linetype = "Beta = 0.8"), color = "black", size = 0.8)  +
#  geom_line(data = us_stats_75_sum, aes(x = date_m, y = med_dep/1000, linetype = "Beta = 0.75"), color = "black", size = 0.8) +
#  geom_line(data = us_stats_70_sum, aes(x = date_m, y = med_dep/1000, linetype = "Beta = 0.7"), color = "black", size = 0.8) +
#  geom_line(data = us_stats_90_sum, aes(x = date_m, y = med_dep/1000, linetype = "Beta = 0.90"), color = "black", size = 0.8) +
  geom_point(data = us_stats_85_sum,  aes(x = date_m, y = med_dep/1000, shape = "Beta = 0.85"), color = "black", size = 1.2)  +
  geom_point(data = us_stats_75_sum, aes(x = date_m, y = med_dep/1000, shape = "Beta = 0.75"), color = "black", size = 1.2) +
  geom_point(data = us_stats_80_sum,  aes(x = date_m, y = med_dep/1000, shape = "Beta = 0.8"), color = "black", size = 1.2)  +
  geom_point(data = us_stats_70_sum, aes(x = date_m, y = med_dep/1000, shape = "Beta = 0.7"), color = "black", size = 1.2) +
  geom_point(data = us_stats_90_sum, aes(x = date_m, y = med_dep/1000, shape = "Beta = 0.90"), color = "black", size = 1.2) +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = m2_fix/1000), color = "black", size = 3) +
  theme_bw() + ylab("USDbn") + xlab("") + 
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 17.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "black") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=0, ymax=25), fill="grey", alpha=0.2) + 
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) +
  guides(shape = guide_legend(nrow = 2,override.aes = list(size = 5)))

dev.copy(pdf,'many_betas_deps_point.pdf')

dev.off()

ggplot() + 
  geom_point(data = us_stats_85_sum,  aes(x = date_m, y = med_mult, shape = "Beta = 0.85"), size = 1.2)  +
  geom_point(data = us_stats_75_sum, aes(x = date_m, y = med_mult, shape = "Beta = 0.75"), size = 1.2) +
  geom_point(data = us_stats_80_sum,  aes(x = date_m, y = med_mult, shape = "Beta = 0.8"), size = 1.2)  +
  geom_point(data = us_stats_70_sum, aes(x = date_m, y = med_mult, shape = "Beta = 0.7"), size = 1.2) +
  geom_point(data = us_stats_90_sum, aes(x = date_m, y = med_mult, shape = "Beta = 0.90"), size = 1.2) +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = (m2_fix+CURRENCY)/(RESERVES+CURRENCY)), color = "black", size = 3) +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "black") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom",legend.text=element_text(size=20)) + 
  guides(shape = guide_legend(nrow = 2,override.aes = list(size = 5)))

dev.copy(pdf,'many_betas_point.pdf')

dev.off()

##### Colours

ggplot() + 
  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = med_mult, color = "Beta = 0.85"), size = 0.8)  +
  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = top_mult, color = "Beta = 0.85"), linetype="dashed")  +
  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = bot_mult, color = "Beta = 0.85"), linetype="dashed")  +
  geom_line(data = us_stats_80_sum,  aes(x = date_m, y = med_mult, color = "Beta = 0.8"), size = 0.8)  +
  geom_line(data = us_stats_80_sum,  aes(x = date_m, y = top_mult, color = "Beta = 0.8"), linetype="dashed")  +
  geom_line(data = us_stats_80_sum,  aes(x = date_m, y = bot_mult, color = "Beta = 0.8"), linetype="dashed")  +
  geom_line(data = us_stats_75_sum, aes(x = date_m, y = med_mult, color = "Beta = 0.75"), size = 0.8) +
  geom_line(data = us_stats_75_sum,  aes(x = date_m, y = top_mult, color = "Beta = 0.75"), linetype="dashed")  +
  geom_line(data = us_stats_75_sum,  aes(x = date_m, y = bot_mult, color = "Beta = 0.75"), linetype="dashed")  +
  geom_line(data = us_stats_70_sum, aes(x = date_m, y = med_mult, color = "Beta = 0.7"), size = 0.8) +
  geom_line(data = us_stats_70_sum,  aes(x = date_m, y = top_mult, color = "Beta = 0.7"), linetype="dashed")  +
  geom_line(data = us_stats_70_sum,  aes(x = date_m, y = bot_mult, color = "Beta = 0.7"), linetype="dashed")  +
  geom_line(data = us_stats_90_sum, aes(x = date_m, y = med_mult, color = "Beta = 0.90"), size = 0.8) +
  geom_line(data = us_stats_90_sum, aes(x = date_m, y = top_mult, color = "Beta = 0.90"), linetype="dashed") +
  geom_line(data = us_stats_90_sum, aes(x = date_m, y = bot_mult, color = "Beta = 0.90"), linetype="dashed") +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = (m2_fix+CURRENCY)/(RESERVES+CURRENCY)), color = "black", size = 1.1) +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) + guides(colour = guide_legend(nrow = 2))

dev.copy(pdf,'many_betas.pdf')

dev.off()

ggplot() + 
  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = med_dep/1000, color = "Beta = 0.85"), size = 0.8)  +
  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = top_dep/1000, color = "Beta = 0.85"), linetype="dashed")  +
  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = bot_dep/1000, color = "Beta = 0.85"), linetype="dashed")  +
  geom_line(data = us_stats_80_sum,  aes(x = date_m, y = med_dep/1000, color = "Beta = 0.8"), size = 0.8)  +
  geom_line(data = us_stats_80_sum,  aes(x = date_m, y = top_dep/1000, color = "Beta = 0.8"), linetype="dashed")  +
  geom_line(data = us_stats_80_sum,  aes(x = date_m, y = bot_dep/1000, color = "Beta = 0.8"), linetype="dashed")  +
  geom_line(data = us_stats_75_sum, aes(x = date_m, y = med_dep/1000, color = "Beta = 0.75"), size = 0.8) +
  geom_line(data = us_stats_75_sum,  aes(x = date_m, y = top_dep/1000, color = "Beta = 0.75"), linetype="dashed")  +
  geom_line(data = us_stats_75_sum,  aes(x = date_m, y = bot_dep/1000, color = "Beta = 0.75"), linetype="dashed")  +
  geom_line(data = us_stats_70_sum, aes(x = date_m, y = med_dep/1000, color = "Beta = 0.7"), size = 0.8) +
  geom_line(data = us_stats_70_sum,  aes(x = date_m, y = top_dep/1000, color = "Beta = 0.7"), linetype="dashed")  +
  geom_line(data = us_stats_70_sum,  aes(x = date_m, y = bot_dep/1000, color = "Beta = 0.7"), linetype="dashed")  +
  geom_line(data = us_stats_90_sum, aes(x = date_m, y = med_dep/1000, color = "Beta = 0.90"), size = 0.8) +
  geom_line(data = us_stats_90_sum, aes(x = date_m, y = top_dep/1000, color = "Beta = 0.90"), linetype="dashed") +
  geom_line(data = us_stats_90_sum, aes(x = date_m, y = bot_dep/1000, color = "Beta = 0.90"), linetype="dashed") +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = m2_fix/1000), color = "black", size = 1.1) +
  theme_bw() + ylab("USDbn") + xlab("") + 
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 17.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=0, ymax=25), fill="grey", alpha=0.2) + 
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) + guides(colour = guide_legend(nrow = 2))

dev.copy(pdf,'many_betas_deps.pdf')

dev.off()


