################# A Model of QE, Reserve Demand, and the Money Multiplier #################
################# Authors: Ellen Ryan and Karl Whelan #################

##############File overview and pre-requisites 

### First run files 3.1 for US data and 5 for model
### Also run file 3.2 to get US calibrated output without capital constraints
## File produces illustrative and then US-calibrated output for Section 6


library(ggplot2)
library(dplyr)

### CHANGE THIS
setwd("C:/Users/ryanell/Desktop/Macro money/R/Charts/D. Capital")
getwd()

############################## Basic illustrative calibration ##############################

b<- 0.99

c<-10
  
d<- 100

y<- 0.02

r <- (d*(1-b+y*b)+y*b*c)/(1+y*b)
r
d+c-r
#Whats the capital ratio?
(d+c-r)/c


########Apply same shock with and without capital constraints


purch <- c(rep(0,5),10,rep(0,200))

mm_model_core_cap_iterations(num_it = 100, i_cb = purch, i_beta_h = b, i_beta_l = b, i_num_banks = 100, 
                             i_sh_low_beta = 0, i_sh_seller = 0.8, i_seller_pp = 0.6,
                             i_res_start = r, i_dep_start = d, i_cap_start = c,
                             i_curr_res = c(rep(5,length(purch))), i_repay = y,
                             i_non_bank_sh = 0.75, i_cap_c = 0.08, i_nim = 0.02,
                             i_print_detail = FALSE)


cap_8<- key_stats

cap_8$total_capital[1]/cap_8$total_loans[1]

cap_8$cap_rat <- cap_8$total_capital/cap_8$total_loans
cap_8_sum<- cap_8 %>%
  group_by(period) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            med_cap = quantile(cap_rat, prob = 0.5), 
            bot_cap = quantile(cap_rat, prob = 0.01), 
            top_cap = quantile(cap_rat, prob = 0.99),
            res = quantile(total_reserves, prob = 0.5),
            curr = quantile(currency, prob = 0.5))



mm_model_core_cap_iterations(num_it = 100, i_cb = purch, i_beta_h = b, i_beta_l = b, i_num_banks = 100, 
                             i_sh_low_beta = 0, i_sh_seller = 0.8, i_seller_pp = 0.6,
                             i_res_start = r, i_dep_start = d, i_cap_start = c,
                             i_curr_res = c(rep(5,length(purch))), i_repay = y,
                             i_non_bank_sh = 0.75, i_cap_c = 0.00000000000000006, i_nim = 0.02,
                             i_print_detail = FALSE)


cap_0<- key_stats

cap_0$cap_rat <- cap_0$total_capital/cap_0$total_loans
cap_0_sum<- cap_0 %>%
  group_by(period) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            med_cap = quantile(cap_rat, prob = 0.5), 
            bot_cap = quantile(cap_rat, prob = 0.01), 
            top_cap = quantile(cap_rat, prob = 0.99),
            res = quantile(total_reserves, prob = 0.5),
            curr = quantile(currency, prob = 0.5))


########### Figure 8 ##########


############Distinguish with linetype

#Money multiplier
ggplot() + 
  geom_line(data = cap_8_sum,  aes(x = period, y = med_mult, linetype = "8% capital requirement"), size = 1, color = "black") + 
#  geom_line(data = cap_8_sum,  aes(x = period, y = bot_mult, color = "8% capital requirement"), linetype="dashed") + 
#geom_line(data = cap_8_sum,  aes(x = period, y = top_mult, color = "8% capital requirement"), linetype="dashed") + 
  geom_line(data = cap_0_sum,  aes(x = period, y = med_mult, linetype = "No capital requirement"), size = 1, color = "black") + 
#  geom_line(data = cap_0_sum,  aes(x = period, y = top_mult, color = "No capital requirement"), linetype="dashed") + 
#  geom_line(data = cap_0_sum,  aes(x = period, y = bot_mult, color = "No capital requirement"), linetype="dashed") + 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))+ guides(linetype = guide_legend(nrow = 2))



dev.copy(pdf,'ill_cap_mult_bw.pdf')

dev.off()


#Capital ratios

ggplot() + 
  geom_line(data = cap_8_sum,  aes(x = period, y = med_cap, linetype = "8% capital requirement"), size = 1, color = "black") + 
 # geom_line(data = cap_8_sum,  aes(x = period, y = bot_cap, color = "8% capital requirement"), linetype="dashed") + 
#  geom_line(data = cap_8_sum,  aes(x = period, y = top_cap, color = "8% capital requirement"), linetype="dashed") + 
  geom_line(data = cap_0_sum,  aes(x = period, y = med_cap, linetype = "No capital requirement"), size = 1, color = "black") + 
#  geom_line(data = cap_0_sum,  aes(x = period, y = top_cap, color = "No capital requirement"), linetype="dashed") + 
#  geom_line(data = cap_0_sum,  aes(x = period, y = bot_cap, color = "No capital requirement"), linetype="dashed") + 
  xlab ("Time period")  +  ylab ("")  + ylim(c(0.06,0.1)) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))+ guides(linetype = guide_legend(nrow = 2))



dev.copy(pdf,'ill_cap_cap_bw.pdf')

dev.off()


#Equilibrium

#Need to add labels to distinguish between Repayments and New deposits

labels <- data.frame(label = c("Repayments","New Deposits"),x_pos = c(50,50),y_pos = c(2.5,3.5))

ggplot() + 
  geom_line(data = cap_8_sum,  aes(x = period, y = y*med_loan, linetype = "8% capital requirement"), size = 1, color = "black") + 
  geom_ribbon(data = cap_8_sum,aes(x=period, ymin=y*bot_loan, ymax=y*top_loan), fill = "grey", alpha=0.5)+
  geom_line(data = cap_0_sum,  aes(x = period, y = y*med_loan, linetype = "No capital requirement"), size = 1, color = "black") + 
  geom_ribbon(data = cap_0_sum,aes(x=period, ymin=y*bot_loan, ymax=y*top_loan), fill = "grey", alpha=0.5)+
  geom_line(data = cap_8_sum,  aes(x = period, y = med_push, linetype = "8% capital requirement"), size = 1, color = "black") + 
  geom_ribbon(data = cap_8_sum,aes(x=period, ymin=bot_push, ymax=top_push), fill = "grey", alpha=0.5)+
  geom_line(data = cap_0_sum,  aes(x = period, y = med_push, linetype = "No capital requirement"), size = 1, color = "black") + 
  geom_ribbon(data = cap_0_sum,aes(x=period, ymin=bot_push, ymax=top_push), fill = "grey", alpha=0.5)+
  xlab ("Time period")  +  ylab ("")  + ylim(c(2,4)) + 
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  geom_text(data=labels, mapping=aes(x=x_pos, y= y_pos, label=label), size=5, angle=0, vjust=-0.4, hjust=0, color = "black") +
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) + guides(linetype = guide_legend(nrow = 2)) +
  guides(linetype = guide_legend(nrow = 2))


dev.copy(pdf,'ill_cap_eq_bw.pdf')

dev.off()


#Reserves held because of capital constraint
ggplot() + geom_line(data = cap_8,  aes(x = period, y = tot_cap_res, color = "8% capital requirement"), size = 1) + 
  geom_line(data = cap_0,  aes(x = period, y = tot_cap_res, color = "No capital requirement"), size = 1) + 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))



#Total deposits

ggplot() + 
  geom_line(data = cap_8_sum,  aes(x = period, y = med_dep,linetype = "8% capital requirement"), size = 1, color = "black") + 
#  geom_line(data = cap_8_sum,  aes(x = period, y = bot_dep, color = "8% capital requirement"), linetype="dashed") + 
#  geom_line(data = cap_8_sum,  aes(x = period, y = top_dep, color = "8% capital requirement"), linetype="dashed") + 
  geom_line(data = cap_0_sum,  aes(x = period, y = med_dep, linetype = "No capital requirement"), size = 1, color = "black") + 
#  geom_line(data = cap_0_sum,  aes(x = period, y = top_dep, color = "No capital requirement"), linetype="dashed") + 
#  geom_line(data = cap_0_sum,  aes(x = period, y = bot_dep, color = "No capital requirement"), linetype="dashed") + 
  xlab ("Time period")  +  ylab ("")  + ylim(c(100,160)) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))+ guides(linetype = guide_legend(nrow = 2))


dev.copy(pdf,'ill_cap_dep_bw.pdf')

dev.off()




#### Distinguish with size

#Money multiplier
ggplot() + 
  geom_line(data = cap_8_sum,  aes(x = period, y = med_mult, size = "8% capital requirement"), color = "black") + 
  #  geom_line(data = cap_8_sum,  aes(x = period, y = bot_mult, color = "8% capital requirement"), linetype="dashed") + 
  #geom_line(data = cap_8_sum,  aes(x = period, y = top_mult, color = "8% capital requirement"), linetype="dashed") + 
  geom_line(data = cap_0_sum,  aes(x = period, y = med_mult, size = "No capital requirement"),  color = "black") + 
  #  geom_line(data = cap_0_sum,  aes(x = period, y = top_mult, color = "No capital requirement"), linetype="dashed") + 
  #  geom_line(data = cap_0_sum,  aes(x = period, y = bot_mult, color = "No capital requirement"), linetype="dashed") + 
  xlab ("Time period")  +  ylab ("")  +
  scale_size_manual(values = c(1,2)) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))+ 
  guides(size = guide_legend(nrow = 2)) + 
  theme(legend.key.width = unit(2,"cm")) 


dev.copy(pdf,'ill_cap_mult_size.pdf')

dev.off()


#Capital ratios

ggplot() + 
  geom_line(data = cap_8_sum,  aes(x = period, y = med_cap, size = "8% capital requirement"),  color = "black") + 
  # geom_line(data = cap_8_sum,  aes(x = period, y = bot_cap, color = "8% capital requirement"), linetype="dashed") + 
  #  geom_line(data = cap_8_sum,  aes(x = period, y = top_cap, color = "8% capital requirement"), linetype="dashed") + 
  geom_line(data = cap_0_sum,  aes(x = period, y = med_cap, size = "No capital requirement"),  color = "black") + 
  #  geom_line(data = cap_0_sum,  aes(x = period, y = top_cap, color = "No capital requirement"), linetype="dashed") + 
  #  geom_line(data = cap_0_sum,  aes(x = period, y = bot_cap, color = "No capital requirement"), linetype="dashed") + 
  xlab ("Time period")  +  ylab ("")  + ylim(c(0.06,0.1)) +
  scale_size_manual(values = c(1,2)) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))+ 
  guides(size = guide_legend(nrow = 2))+ 
  theme(legend.key.width = unit(2,"cm")) 



dev.copy(pdf,'ill_cap_cap_size.pdf')

dev.off()


#Equilibrium

ggplot() + 
  geom_line(data = cap_8_sum,  aes(x = period, y = y*med_loan, size = "8% capital requirement", linetype = "Repayments"), color = "black") + 
  geom_ribbon(data = cap_8_sum,aes(x=period, ymin=y*bot_loan, ymax=y*top_loan), fill = "grey", alpha=0.5)+
  geom_line(data = cap_0_sum,  aes(x = period, y = y*med_loan, size = "No capital requirement", linetype = "Repayments"), color = "black") + 
  geom_ribbon(data = cap_0_sum,aes(x=period, ymin=y*bot_loan, ymax=y*top_loan), fill = "grey", alpha=0.5)+
  geom_line(data = cap_8_sum,  aes(x = period, y = med_push, size = "8% capital requirement", linetype = "New Deposits"),  color = "black") + 
  geom_ribbon(data = cap_8_sum,aes(x=period, ymin=bot_push, ymax=top_push), fill = "grey", alpha=0.5)+
  geom_line(data = cap_0_sum,  aes(x = period, y = med_push, size = "No capital requirement", linetype = "New Deposits"),  color = "black") + 
  geom_ribbon(data = cap_0_sum,aes(x=period, ymin=bot_push, ymax=top_push), fill = "grey", alpha=0.5)+
  scale_size_manual(values = c(1,2)) +
  xlab ("Time period")  +  ylab ("")  + ylim(c(2,4)) + 
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  geom_text(data=labels, mapping=aes(x=x_pos, y= y_pos, label=label), size=5, angle=0, vjust=-0.4, hjust=0, color = "black") +
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=15)) + guides(colour = guide_legend(nrow = 2)) +
  guides(size = guide_legend(nrow = 2))+ guides(linetype = guide_legend(nrow = 2))+ 
  theme(legend.key.width = unit(2,"cm")) 



dev.copy(pdf,'ill_cap_eq_size.pdf')

dev.off()



#Total deposits

ggplot() + 
  geom_line(data = cap_8_sum,  aes(x = period, y = med_dep,size = "8% capital requirement"),color = "black") + 
  #  geom_line(data = cap_8_sum,  aes(x = period, y = bot_dep, color = "8% capital requirement"), linetype="dashed") + 
  #  geom_line(data = cap_8_sum,  aes(x = period, y = top_dep, color = "8% capital requirement"), linetype="dashed") + 
  geom_line(data = cap_0_sum,  aes(x = period, y = med_dep, size = "No capital requirement"), color = "black") + 
  #  geom_line(data = cap_0_sum,  aes(x = period, y = top_dep, color = "No capital requirement"), linetype="dashed") + 
  #  geom_line(data = cap_0_sum,  aes(x = period, y = bot_dep, color = "No capital requirement"), linetype="dashed") + 
  xlab ("Time period")  +  ylab ("")  + ylim(c(100,160)) +
  scale_size_manual(values = c(1,2)) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))+ 
  guides(size = guide_legend(nrow = 2))+ 
  theme(legend.key.width = unit(2,"cm")) 


dev.copy(pdf,'ill_cap_dep_size.pdf')

dev.off()







############################## Repeated QE with breaks in between ##############################

### Calibration with beta = 0.8

b2<- 0.85

c2<-8

d2<- 100

y2<- 0.02

r2 <- (d*(1-b+y*b)+y*b*c)/(1+y*b)
r2

#Whats the capital ratio?
(d2+c2-r2)/c2


purch_rep <- c(rep(0,5),rep(50,20),rep(0,50),rep(50,20),rep(0,50),rep(50,20),rep(0,70))





mm_model_core_cap_iterations(num_it = 100, i_cb = purch_rep, i_beta_h = b2, i_beta_l = b2, i_num_banks = 10, 
                             i_sh_low_beta = 0, i_sh_seller = 0.8, i_seller_pp = 0.6,
                             i_res_start = r2, i_dep_start = d2, i_cap_start = c2,
                             i_curr_res = c(rep(5,length(purch_rep))), i_repay = y2,
                             i_non_bank_sh = 0.75, i_cap_c = 0.1, i_nim = 0.02,
                             i_print_detail = FALSE)


cap_10_rep<- key_stats

cap_10_rep$cap_rat <- cap_10_rep$total_capital/cap_10_rep$total_loans
cap_10_rep_sum<- cap_10_rep %>%
  group_by(period) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            med_cap = quantile(cap_rat, prob = 0.5), 
            bot_cap = quantile(cap_rat, prob = 0.01), 
            top_cap = quantile(cap_rat, prob = 0.99),
            res = quantile(total_reserves, prob = 0.5),
            curr = quantile(currency, prob = 0.5))


mm_model_core_cap_iterations(num_it = 100, i_cb = purch_rep, i_beta_h = b2, i_beta_l = b2, i_num_banks = 10, 
                             i_sh_low_beta = 0, i_sh_seller = 0.8, i_seller_pp = 0.6,
                             i_res_start = r2, i_dep_start = d2, i_cap_start = c2,
                             i_curr_res = c(rep(5,length(purch_rep))), i_repay = y2,
                             i_non_bank_sh = 0.75, i_cap_c = 0.00000000000000006, i_nim = 0.02,
                             i_print_detail = FALSE)


cap_0_rep<- key_stats

cap_0_rep$cap_rat <- cap_0_rep$total_capital/cap_0_rep$total_loans
cap_0_rep_sum<- cap_0_rep %>%
  group_by(period) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            med_cap = quantile(cap_rat, prob = 0.5), 
            bot_cap = quantile(cap_rat, prob = 0.01), 
            top_cap = quantile(cap_rat, prob = 0.99),
            res = quantile(total_reserves, prob = 0.5),
            curr = quantile(currency, prob = 0.5))


##### Figure 9 #####

#Total deposits

ggplot() + 
  geom_line(data = cap_10_rep_sum,  aes(x = period, y = med_dep, linetype = "10% capital requirement"), size = 1,color = "black") + 
#  geom_line(data = cap_10_rep_sum,  aes(x = period, y = bot_dep, color = "10% capital requirement"), linetype="dashed") + 
#  geom_line(data = cap_10_rep_sum,  aes(x = period, y = top_dep, color = "10% capital requirement"), linetype="dashed") + 
  geom_line(data = cap_0_rep_sum,  aes(x = period, y = med_dep, linetype = "No capital requirement"), size = 1,color = "black") + 
# geom_line(data = cap_0_rep_sum,  aes(x = period, y = top_dep, color = "No capital requirement"), linetype="dashed") + 
#  geom_line(data = cap_0_rep_sum,  aes(x = period, y = bot_dep, color = "No capital requirement"), linetype="dashed") + 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))+ guides(colour = guide_legend(nrow = 2))


dev.copy(pdf,'ill_cap_rep_dep_bw.pdf')

dev.off()

ggplot() + 
  geom_line(data = cap_10_rep_sum,  aes(x = period, y = med_dep, size = "10% capital requirement"), color = "black") + 
  #  geom_line(data = cap_10_rep_sum,  aes(x = period, y = bot_dep, color = "10% capital requirement"), linetype="dashed") + 
  #  geom_line(data = cap_10_rep_sum,  aes(x = period, y = top_dep, color = "10% capital requirement"), linetype="dashed") + 
  geom_line(data = cap_0_rep_sum,  aes(x = period, y = med_dep, size = "No capital requirement"), color = "black") + 
  # geom_line(data = cap_0_rep_sum,  aes(x = period, y = top_dep, color = "No capital requirement"), linetype="dashed") + 
  #  geom_line(data = cap_0_rep_sum,  aes(x = period, y = bot_dep, color = "No capital requirement"), linetype="dashed") + 
  xlab ("Time period")  +  ylab ("")  +
  scale_size_manual(values = c(1,2)) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))+ guides(size = guide_legend(nrow = 2))


dev.copy(pdf,'ill_cap_rep_dep_size.pdf')

dev.off()

#Equilibirum


labels2 <- data.frame(label = c("Repayments","New Deposits"),x_pos = c(30,10,215,215),y_pos = c(9,55,40,90))


ggplot() + 
  geom_line(data = cap_10_rep_sum,  aes(x = period, y = y*med_loan, linetype = "10% capital requirement", linetype = "Repayments"), size = 1) + 
  geom_ribbon(data = cap_10_rep_sum,aes(x=period, ymin=y*bot_loan, ymax=y*top_loan), fill = "grey", alpha=0.5)+
  geom_line(data = cap_0_rep_sum,  aes(x = period, y = y*med_loan, linetype = "No capital requirement", linetype = "Repayments"), size = 1) + 
  geom_ribbon(data = cap_0_rep_sum,aes(x=period, ymin=y*bot_loan, ymax=y*top_loan), fill = "grey", alpha=0.5)+
  geom_line(data = cap_10_rep_sum,  aes(x = period, y = med_push, linetype = "10% capital requirement", linetype = "New deposits"), size = 1) + 
  geom_ribbon(data = cap_10_rep_sum,aes(x=period, ymin=bot_push, ymax=top_push), fill = "grey", alpha=0.5)+
  geom_line(data = cap_0_rep_sum,  aes(x = period, y = med_push, linetype = "No capital requirement", linetype = "New deposits"), size = 1) + 
  geom_ribbon(data = cap_0_rep_sum,aes(x=period, ymin=bot_push, ymax=top_push), fill = "grey", alpha=0.5)+
  xlab ("Time period")  +  ylab ("")  + ylim(c(0,100)) +
  geom_text(data=labels2, mapping=aes(x=x_pos, y= y_pos, label=label), size=5, angle=0, vjust=-0.4, hjust=0, color = "black") +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=15)) + guides(colour = guide_legend(nrow = 2)) +
  guides(linetype = guide_legend(nrow = 2))



dev.copy(pdf,'ill_cap_rep_eq_bw.pdf')

dev.off()


ggplot() + 
  geom_line(data = cap_10_rep_sum,  aes(x = period, y = y*med_loan, size = "10% capital req.", linetype = "Repayments")) + 
  geom_ribbon(data = cap_10_rep_sum,aes(x=period, ymin=y*bot_loan, ymax=y*top_loan), fill = "grey", alpha=0.5)+
  geom_line(data = cap_0_rep_sum,  aes(x = period, y = y*med_loan, size = "No capital req.", linetype = "Repayments")) + 
  geom_ribbon(data = cap_0_rep_sum,aes(x=period, ymin=y*bot_loan, ymax=y*top_loan), fill = "grey", alpha=0.5)+
  geom_line(data = cap_10_rep_sum,  aes(x = period, y = med_push, size = "10% capital req.", linetype = "New deposits")) + 
  geom_ribbon(data = cap_10_rep_sum,aes(x=period, ymin=bot_push, ymax=top_push), fill = "grey", alpha=0.5)+
  geom_line(data = cap_0_rep_sum,  aes(x = period, y = med_push, size = "No capital req.", linetype = "New deposits")) + 
  geom_ribbon(data = cap_0_rep_sum,aes(x=period, ymin=bot_push, ymax=top_push), fill = "grey", alpha=0.5)+
  xlab ("Time period")  +  ylab ("")  + ylim(c(0,100)) +
  scale_size_manual(values = c(1,2)) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=15)) + 
  guides(linetype = guide_legend(nrow = 2)) + guides(size = guide_legend(nrow = 2)) + theme(legend.key.width = unit(3,"cm")) 


dev.copy(pdf,'ill_cap_rep_eq_size.pdf')

dev.off()


#Money multiplier
ggplot() + geom_line(data = cap_8_rep,  aes(x = period, y = model_money_mult, color = "8% capital requirement"), size = 1) + 
  geom_line(data = cap_0_rep,  aes(x = period, y = model_money_mult, color = "No capital requirement"), size = 1) + 
  xlab ("Time period")  +  ylab ("")  +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20))



################################## US calibration #################################


cap_constraint <- c(0.06,0.12,0.08)


start_capital <- cap_constraint*(us_mon_agg2$m2_fix[1]-us_mon_agg2$RESERVES[1])

### Run model for each capital constraint option - with beta = 0.99 

mm_model_core_cap_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.99, 
                             i_beta_l = 0.99,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr, i_cap_start = start_capital[1],
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_cap_c = cap_constraint[1], i_nim = 0.01,
                             i_print_detail = FALSE)


us_cap_base_1<-key_stats

us_cap_base_1$model_money_mult[1]
us_mon_agg2$money_mult[1]

us_cap_base_1$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_cap_base_1_sum<- us_cap_base_1 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            res = quantile(total_reserves, prob = 0.5),
            curr = quantile(currency, prob = 0.5))

us_cap_base_1_sum$period <-seq(1,nrow(us_mon_agg2))



mm_model_core_cap_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.99, 
                             i_beta_l = 0.99,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr, i_cap_start = start_capital[2],
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_cap_c = cap_constraint[2], i_nim = 0.01,
                             i_print_detail = FALSE)


us_cap_base_2<-key_stats

us_cap_base_2$model_money_mult[1]
us_mon_agg2$money_mult[1]

us_cap_base_2$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_cap_base_2_sum<- us_cap_base_2 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            res = quantile(total_reserves, prob = 0.5),
            curr = quantile(currency, prob = 0.5))

us_cap_base_2_sum$period <-seq(1,nrow(us_mon_agg2))



###### Figure 10 #######
ggplot() + 
  geom_line(data = us_stats_b_sum[which(us_stats_b_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = med_mult, linetype = "Without capital constraint"), color = "black",  size = 1.2)  +
#  geom_line(data = us_stats_b_sum[which(us_stats_b_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = top_mult, color = "Without capital constraint"), linetype="dashed")  +
#  geom_line(data = us_stats_b_sum[which(us_stats_b_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = bot_mult, color = "Without capital constraint"), linetype="dashed")  +
  geom_line(data = us_cap_base_1_sum[which(us_cap_base_1_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = med_mult, linetype = "6% constraint"), color = "black", size = 1.2)  +
#  geom_line(data = us_cap_base_1_sum[which(us_cap_base_1_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = top_mult, color = "6% constraint"), linetype="dashed")  +
#  geom_line(data = us_cap_base_1_sum[which(us_cap_base_1_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = bot_mult, color = "6% constraint"), linetype="dashed")  +
  geom_line(data = us_cap_base_2_sum[which(us_cap_base_2_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = med_mult, linetype = "12% constraint"), color = "black", size = 1.2)  +
#  geom_line(data = us_cap_base_2_sum[which(us_cap_base_2_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = top_mult, color = "12% constraint"), linetype="dashed")  +
#  geom_line(data = us_cap_base_2_sum[which(us_cap_base_2_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = bot_mult, color = "12% constraint"), linetype="dashed")  +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = (m2_fix+CURRENCY)/(RESERVES+CURRENCY)), color = "black", size = 3) +
  ylab("") + xlab("") + 
  scale_linetype_manual(values = c("dotted","dashed","dotdash")) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018")) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) + guides(linetype = guide_legend(nrow = 3)) +
  theme(legend.key.width = unit(3,"cm")) 


dev.copy(pdf,'us_baseline_capital_mult_bw.pdf')

dev.off()

ggplot() + 
  geom_line(data = us_cap_base_2_sum[which(us_cap_base_2_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = med_dep/1000, linetype = "12% constraint"), color = "black", size = 1.2)  +
  #  geom_line(data = us_cap_base_2_sum[which(us_cap_base_2_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = top_mult, color = "12% constraint"), linetype="dashed")  +
  #  geom_line(data = us_cap_base_2_sum[which(us_cap_base_2_sum$med_mult < us_stats_b_sum$med_mult[1]),],  aes(x = date_m, y = bot_mult, color = "12% constraint"), linetype="dashed")  +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = m2_fix/1000), color = "black", size = 3) +
  ylab("") + xlab("") + 
  scale_linetype_manual(values = c("dotted","dashed","dotdash")) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018")) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) + guides(linetype = guide_legend(nrow = 3)) +
  theme(legend.key.width = unit(3,"cm")) 


dev.copy(pdf,'us_baseline_capital_dep_bw.pdf')

dev.off()


### Run model for each capital constraint option - with beta = 0.85

mm_model_core_cap_iterations(num_it = 10, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                             i_beta_l = 0.85,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr, i_cap_start = start_capital[1],
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_cap_c = cap_constraint[1], i_nim = 0.01,
                             i_print_detail = FALSE)


us_cap_1<-key_stats
us_cap_1$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_cap_1_sum<- us_cap_1 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            med_res_unw = quantile(tot_cap_res, prob = 0.5), 
            bot_res_unw = quantile(tot_cap_res, prob = 0.01), 
            top_res_unw = quantile(tot_cap_res, prob = 0.99))


mm_model_core_cap_iterations(num_it = 10, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                             i_beta_l = 0.85,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr, i_cap_start = start_capital[3],
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_cap_c = cap_constraint[3], i_nim = 0.01,
                             i_print_detail = FALSE)


us_cap_3<-key_stats
us_cap_3$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_cap_3_sum<- us_cap_3 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            med_res_unw = quantile(tot_cap_res, prob = 0.5), 
            bot_res_unw = quantile(tot_cap_res, prob = 0.01), 
            top_res_unw = quantile(tot_cap_res, prob = 0.99))


mm_model_core_cap_iterations(num_it = 10, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                             i_beta_l = 0.85,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr, i_cap_start = start_capital[2],
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_cap_c = cap_constraint[2], i_nim = 0.01,
                             i_print_detail = FALSE)


us_cap_2<-key_stats
us_cap_2$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_cap_2_sum<- us_cap_2 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            med_res_unw = quantile(tot_cap_res, prob = 0.5), 
            bot_res_unw = quantile(tot_cap_res, prob = 0.01), 
            top_res_unw = quantile(tot_cap_res, prob = 0.99))


###### Figure 11 #######
ggplot() + 
  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = med_mult, linetype = "Without capital constraint"), color = "black", size = 1.2)  +
#  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = top_mult, color = "Without capital constraint"), linetype="dashed")  +
#  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = bot_mult, color = "Without capital constraint"), linetype="dashed")  +
  geom_line(data = us_cap_1_sum,  aes(x = date_m, y = med_mult, linetype = "6% constraint"), color = "black", size = 1.2)  +
#  geom_line(data = us_cap_1_sum,  aes(x = date_m, y = top_mult, color = "6% constraint"), linetype="dashed")  +
#  geom_line(data = us_cap_1_sum,  aes(x = date_m, y = bot_mult, color = "6% constraint"), linetype="dashed")  +
  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = med_mult, linetype = "12% constraint"), color = "black", size = 1.2)  +
#  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = top_mult, color = "12% constraint"), linetype="dashed")  +
#  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = bot_mult, color = "12% constraint"), linetype="dashed")  +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = (m2_fix+CURRENCY)/(RESERVES+CURRENCY)), color = "black", size = 3) +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_linetype_manual(values = c("dotted","dashed","dotdash")) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) +
  guides(linetype = guide_legend(nrow = 3)) + theme(legend.key.width = unit(3,"cm")) 


dev.copy(pdf,'us_cap_mult_bw.pdf')

dev.off()


ggplot() + 
  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = med_dep/1000, linetype = "Without capital constraint"), color = "black", size = 1.2)  +
#  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = top_dep/1000, color = "Without capital constraint"), linetype="dashed")  +
#  geom_line(data = us_stats_85_sum,  aes(x = date_m, y = bot_dep/1000, color = "Without capital constraint"), linetype="dashed")  +
  geom_line(data = us_cap_1_sum,  aes(x = date_m, y = med_dep/1000, linetype = "8% constraint"), color = "black", size = 1.2)  +
#  geom_line(data = us_cap_1_sum,  aes(x = date_m, y = top_dep/1000, color = "8% constraint"), linetype="dashed")  +
#  geom_line(data = us_cap_1_sum,  aes(x = date_m, y = bot_dep/1000, color = "8% constraint"), linetype="dashed")  +
  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = med_dep/1000, linetype = "12% constraint"), color = "black", size = 1.2)  +
#  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = top_dep/1000, color = "12% constraint"), linetype="dashed")  +
#  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = bot_dep/1000, color = "12% constraint"), linetype="dashed")  +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = m2_fix/1000), color = "black", size = 3) +
  theme_bw() + ylab("USDbn") + xlab("") + 
  scale_linetype_manual(values = c("dotted","dashed","dotdash")) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 15, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=0, ymax=20), fill="grey", alpha=0.2) + 
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) + 
  guides(linetype = guide_legend(nrow = 3)) + theme(legend.key.width = unit(3,"cm")) 

dev.copy(pdf,'us_cap_dep_bw.pdf')

dev.off()

ggplot() +
  geom_line(data = us_cap_1_sum,  aes(x = date_m, y = med_res_unw, color = "B. 8% constraint"), size = 0.8)  +
  geom_line(data = us_cap_1_sum,  aes(x = date_m, y = top_res_unw, color = "B. 8% constraint"), linetype="dashed")  +
  geom_line(data = us_cap_1_sum,  aes(x = date_m, y = bot_res_unw, color = "B. 8% constraint"), linetype="dashed")  +
  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = med_res_unw, color = "C. 15% constraint"), size = 0.8)  +
  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = top_res_unw, color = "C. 15% constraint"), linetype="dashed")  +
  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = bot_res_unw, color = "C. 15% constraint"), linetype="dashed")  +
  geom_line(data = us_cap_3_sum,  aes(x = date_m, y = med_res_unw, color = "D. 20% constraint"), size = 0.8)  +
  geom_line(data = us_cap_3_sum,  aes(x = date_m, y = top_res_unw, color = "D. 20% constraint"), linetype="dashed")  +
  geom_line(data = us_cap_3_sum,  aes(x = date_m, y = bot_res_unw, color = "D. 20% constraint"), linetype="dashed")  +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) + 
  guides(linetype = guide_legend(nrow = 3)) + theme(legend.key.width = unit(3,"cm")) 


##########What about very low beta and capital requirements? Which is driving results?

mm_model_core_cap_iterations(num_it = 10, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.2, 
                             i_beta_l = 0.99,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr, i_cap_start = start_capital[1],
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_cap_c = cap_constraint[1], i_nim = 0.01,
                             i_print_detail = FALSE)


us_cap_lowbeta_1<-key_stats

us_cap_lowbeta_1$model_money_mult[1]
us_mon_agg2$money_mult[1]

us_cap_lowbeta_1$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_cap_lowbeta_1_sum<- us_cap_lowbeta_1 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            res = quantile(total_reserves, prob = 0.5),
            curr = quantile(currency, prob = 0.5))

us_cap_lowbeta_1_sum$period <-seq(1,nrow(us_mon_agg2))



mm_model_core_cap_iterations(num_it = 10, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.2, 
                             i_beta_l = 0.99,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr, i_cap_start = start_capital[2],
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_cap_c = cap_constraint[2], i_nim = 0.01,
                             i_print_detail = FALSE)


us_cap_lowbeta_2<-key_stats

us_cap_lowbeta_2$model_money_mult[1]
us_mon_agg2$money_mult[1]

us_cap_lowbeta_2$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_cap_lowbeta_2_sum<- us_cap_lowbeta_2 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            res = quantile(total_reserves, prob = 0.5),
            curr = quantile(currency, prob = 0.5))

us_cap_lowbeta_2_sum$period <-seq(1,nrow(us_mon_agg2))


###### Figure 12 #######

ggplot() + 
  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = med_mult, linetype = "12% constraint, Beta = 0.85"), color = "black", size = 1.2)  +
#  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = top_mult, color = "12% constraint, Beta = 0.85"), linetype="dashed")  +
#  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = bot_mult, color = "12% constraint, Beta = 0.85"), linetype="dashed")  +
  geom_line(data = us_cap_lowbeta_2_sum,  aes(x = date_m, y = med_mult, linetype = "12% constraint, Beta = 0.2"), color = "black", size = 1.2)  +
#  geom_line(data = us_cap_lowbeta_2_sum,  aes(x = date_m, y = top_mult, color = "12% constraint, Beta = 0.2"), linetype="dashed")  +
#  geom_line(data = us_cap_lowbeta_2_sum,  aes(x = date_m, y = bot_mult, color = "12% constraint, Beta = 0.2"), linetype="dashed")  +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = (m2_fix+CURRENCY)/(RESERVES+CURRENCY)), color = "black", size = 3) +
  theme_bw() + ylab("") + xlab("") + 
  scale_linetype_manual(values = c("dashed","dotted")) +
  scale_y_continuous(breaks=seq(0,8,2), limits = c(0,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "black") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=0, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) + 
  guides(linetype = guide_legend(nrow = 3)) + theme(legend.key.width = unit(3,"cm")) 


dev.copy(pdf,'us_cap12_lowbeta_mult_bw.pdf')

dev.off()

ggplot() + 
  geom_line(data = us_cap_2_sum,  aes(x = date_m, y = med_dep/1000, linetype = "12% constraint, Beta = 0.85"), size = 1.2)  +
 # geom_line(data = us_cap_2_sum,  aes(x = date_m, y = top_dep/1000, color = "12% constraint, Beta = 0.85"), linetype="dashed")  +
 # geom_line(data = us_cap_2_sum,  aes(x = date_m, y = bot_dep/1000, color = "12% constraint, Beta = 0.85"), linetype="dashed")  +
  geom_line(data = us_cap_lowbeta_2_sum,  aes(x = date_m, y = med_dep/1000, linetype = "12% constraint, Beta = 0.2"), size = 1.2)  +
 # geom_line(data = us_cap_lowbeta_2_sum,  aes(x = date_m, y = top_dep/1000, color = "12% constraint, Beta = 0.2"), linetype="dashed")  +
#  geom_line(data = us_cap_lowbeta_2_sum,  aes(x = date_m, y = bot_dep/1000, color = "12% constraint, Beta = 0.2"), linetype="dashed")  +
  geom_line(data = us_mon_agg2, aes(x = date_m, y = m2_fix/1000), color = "black", size = 3) +
  theme_bw() + ylab("USDbn") + xlab("") + 
  scale_linetype_manual(values = c("dashed","dotted")) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 15, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "black") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=0, ymax=20), fill="grey", alpha=0.2) + 
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=20)) + theme(axis.text.x = element_text(size=20)) + theme(axis.text.y = element_text(size=20)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=20)) + 
  guides(linetype = guide_legend(nrow = 3)) + theme(legend.key.width = unit(3,"cm")) 


dev.copy(pdf,'us_cap12_lowbeta_dep_bw.pdf')

dev.off()