################# A Model of QE, Reserve Demand, and the Money Multiplier #################
################# Authors: Ellen Ryan and Karl Whelan #################

##############File overview and pre-requisites 

### First run files 3.1 for US data and 1 for original model
## File produces output Appendix C where model parameters that 
## cannot be calibrated from FRED data are varied within credible ranges



##################### Set-up

library(ggplot2)
library(dplyr)

setwd("C:/Users/ryanell/Desktop/Macro money/R/Charts/E. Microparameters")
getwd()



################################################ Baseline ########################################################


mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                             i_beta_l =0.1,
                             i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.8,i_seller_pp = 0.6,  
                             i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                             i_curr_res= us_mon_agg2$cr,
                             i_non_bank_sh = 0.9, i_repay = 0.01, 
                             i_print_detail = FALSE)


us_panel_85<- bank_panel
us_stats_85<-key_stats
us_stats_85$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)


us_stats_85_sum<- us_stats_85 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(model_money_mult, prob = 0.5), 
            bot_mult = quantile(model_money_mult, prob = 0.01), 
            top_mult = quantile(model_money_mult, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99),
            med_short = quantile(perc_res_def, prob = 0.5), 
            bot_short = quantile(perc_res_def, prob = 0.01), 
            top_short = quantile(perc_res_def, prob = 0.99))


################################## #################   ROLE OF MARKET STRUCTURE    ##################### ##################################


###########################################################  Effect of most extreme assumptions  ##########################################

################################## No market structure assumptions - everyone buys all the time

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                         i_beta_l =0.1,
                         i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 1, i_seller_pp = 1, 
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0.90,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_all_sell<- bank_panel
us_stats_all_always<-key_stats
us_stats_all_always$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_all_always$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_all_always$money_mult2<-(us_stats_all_always$curr_real+us_stats_all_always$total_deposits)/(us_stats_all_always$curr_real+us_stats_all_always$total_reserves)

us_stats_all_always_sum<- us_stats_all_always %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))


################################## One bank does everything

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                         i_beta_l =0.1,
                         i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.01, i_seller_pp = 0.01, 
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0.90,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_one_bank<- bank_panel
us_stats_one_bank<-key_stats
us_stats_one_bank$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_one_bank$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_one_bank$money_mult2<-(us_stats_one_bank$curr_real+us_stats_one_bank$total_deposits)/(us_stats_one_bank$curr_real+us_stats_one_bank$total_reserves)

us_stats_one_bank_sum<- us_stats_one_bank %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))


##### Figure 1 a) ##### 

##Black and white


ggplot() + geom_line(data = us_stats_all_always_sum,  aes(x = date_m, y = med_mult, linetype = "2. All banks"), size = 1.2)  +
  geom_line(data = us_stats_one_bank_sum,  aes(x = date_m, y = med_mult, linetype = "3. Same bank"), size = 1.2)  +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = med_mult, linetype = "1. Baseline"), size = 1.2) +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=14)) + theme(axis.text.x = element_text(size=14)) + theme(axis.text.y = element_text(size=14)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + 
  theme(legend.text=element_text(size=14)) + guides(linetype = guide_legend(nrow = 2))+
  theme(legend.key.width = unit(3,"cm")) 


dev.copy(pdf,'ext_market_struct_bw.pdf')

dev.off()

## COlor


ggplot() + geom_line(data = us_stats_all_always_sum,  aes(x = date_m, y = med_mult, color = "2. All banks"), size = 0.8)  +
  geom_line(data = us_stats_all_always_sum,  aes(x = date_m, y = bot_mult, color = "2. All banks"), linetype="dashed")  +
  geom_line(data = us_stats_all_always_sum,  aes(x = date_m, y = top_mult, color = "2. All banks"), linetype="dashed")  +
  geom_line(data = us_stats_one_bank_sum,  aes(x = date_m, y = med_mult, color = "3. Same bank"), size = 0.8)  +
  geom_line(data = us_stats_one_bank_sum,  aes(x = date_m, y = bot_mult, color = "3. Same bank"), linetype="dashed")  +
  geom_line(data = us_stats_one_bank_sum,  aes(x = date_m, y = top_mult, color = "3. Same bank"), linetype="dashed")  + 
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = med_mult, color = "1. Baseline"), size = 0.8) +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = bot_mult, color = "1. Baseline"), linetype="dashed") +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = top_mult, color = "1. Baseline"), linetype="dashed") +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=14)) + theme(axis.text.x = element_text(size=14)) + theme(axis.text.y = element_text(size=14)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=14)) + guides(colour = guide_legend(nrow = 2))


dev.copy(pdf,'ext_market_struct.pdf')

dev.off()


##### Re-do this with pre-QE data


mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 1-(us_mon_agg2$RESERVES[1]/us_mon_agg2$m2_fix[1]), 
                         i_beta_l =0.1,
                         i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 1, i_seller_pp = 1, 
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0.90,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_all_sell<- bank_panel
us_stats_all_always_bb<-key_stats
us_stats_all_always_bb$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_all_always_bb$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_all_always_bb$money_mult2<-(us_stats_all_always_bb$curr_real+us_stats_all_always_bb$total_deposits)/(us_stats_all_always_bb$curr_real+us_stats_all_always_bb$total_reserves)

us_stats_all_always_bb_sum<- us_stats_all_always_bb %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))


################################## One bank does everything

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 1-(us_mon_agg2$RESERVES[1]/us_mon_agg2$m2_fix[1]), 
                         i_beta_l =0.1,
                         i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = 0.01, i_seller_pp = 0.01, 
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0.90,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_one_bank_bb<- bank_panel
us_stats_one_bank_bb<-key_stats
us_stats_one_bank_bb$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_one_bank_bb$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_one_bank_bb$money_mult2<-(us_stats_one_bank_bb$curr_real+us_stats_one_bank_bb$total_deposits)/(us_stats_one_bank_bb$curr_real+us_stats_one_bank_bb$total_reserves)

us_stats_one_bank_bb_sum<- us_stats_one_bank_bb %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))


us_stats_one_bank_bb_sum$period <- seq(1,nrow(us_mon_agg2))

us_stats_all_always_bb_sum$period <- seq(1,nrow(us_mon_agg2))

#### Figure 1 b) #####

### Black and white

##Main chart for paper
ggplot() + geom_line(data=us_stats_b_sum[which(us_stats_b_sum$period <17),], aes(x = date_m, y = med_mult, linetype = "1. Baseline"), size = 1.2) +
  geom_line(data=us_stats_one_bank_bb_sum[which(us_stats_one_bank_bb_sum$period <17),], aes(x = date_m, y = med_mult, linetype = "3. Same bank"), size = 1.2) +
  geom_line(data=us_stats_all_always_bb_sum[which(us_stats_all_always_bb_sum$period <17),], aes(x = date_m, y = med_mult, linetype = "2. All banks"), size = 0.8) +
  geom_line(data = us_mon_agg2[which(us_mon_agg2$period <17),], aes(x = date_m, y = (m2_fix+CURRENCY)/(RESERVES+CURRENCY)), color = "black", size = 3) +
  theme_bw() + ylab("") + xlab("") +    scale_y_continuous(breaks=seq(4,8,1), limits = c(4,8.2)) +   
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + 
  theme_bw()+   theme(text = element_text(size=14)) + 
  theme(axis.text.x = element_text(size=14)) + theme(axis.text.y = element_text(size=14)) +   
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + 
  theme(legend.text=element_text(size=14)) + 
  guides(linetype = guide_legend(nrow = 2)) +
  theme(legend.key.width = unit(3,"cm")) 
  



dev.copy(pdf,'initial_impact_ext_market_structure_bw.pdf')

dev.off()

### Color


##Main chart for paper
ggplot() + geom_line(data=us_stats_b_sum[which(us_stats_b_sum$period <17),], aes(x = date_m, y = med_mult, color = "1. Baseline"), size = 0.8) +
  geom_line(data=us_stats_b_sum[which(us_stats_b_sum$period <17),], aes(x = date_m, y = bot_mult, color = "1. Baseline"), linetype="dashed") +
  geom_line(data=us_stats_b_sum[which(us_stats_b_sum$period <17),], aes(x = date_m, y = top_mult, color = "1. Baseline"), linetype="dashed") +
  geom_line(data=us_stats_one_bank_bb_sum[which(us_stats_one_bank_bb_sum$period <17),], aes(x = date_m, y = med_mult, color = "3. Same bank"), size = 0.8) +
  geom_line(data=us_stats_one_bank_bb_sum[which(us_stats_one_bank_bb_sum$period <17),], aes(x = date_m, y = bot_mult, color = "3. Same bank"), linetype="dashed") +
  geom_line(data=us_stats_one_bank_bb_sum[which(us_stats_one_bank_bb_sum$period <17),], aes(x = date_m, y = top_mult, color = "3. Same bank"), linetype="dashed") +
  geom_line(data=us_stats_all_always_bb_sum[which(us_stats_all_always_bb_sum$period <17),], aes(x = date_m, y = med_mult, color = "2. All banks"), size = 0.8) +
  geom_line(data=us_stats_all_always_bb_sum[which(us_stats_all_always_bb_sum$period <17),], aes(x = date_m, y = bot_mult, color = "2. All banks"), linetype="dashed") +
  geom_line(data=us_stats_all_always_bb_sum[which(us_stats_all_always_bb_sum$period <17),], aes(x = date_m, y = top_mult, color = "2. All banks"), linetype="dashed") +
  geom_line(data = us_mon_agg2[which(us_mon_agg2$period <17),], aes(x = date_m, y = (m2_fix+CURRENCY)/(RESERVES+CURRENCY)), color = "black", size = 1) +
  theme_bw() + ylab("") + xlab("") +    scale_y_continuous(breaks=seq(4,8,1), limits = c(4,8.2)) +   
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+   theme(text = element_text(size=14)) + theme(axis.text.x = element_text(size=14)) + theme(axis.text.y = element_text(size=14)) +   theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=14)) + guides(colour = guide_legend(nrow = 2))



dev.copy(pdf,'initial_impact_ext_market_structure.pdf')

dev.off()



###########################################################  Plausible alternative market structure  ##########################################




plaus_alts<- data.frame(scenario = seq(1,3),
                        i_sh_seller = c(0.6,1,0.1),
                        i_seller_pp = c(0.4,0.9,0.1))

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                         i_beta_l =0.1,
                         i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = plaus_alts$i_sh_seller[1], i_seller_pp = plaus_alts$i_seller_pp[1], 
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0.90,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_plaus1<- bank_panel
us_stats_plaus1<-key_stats
us_stats_plaus1$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_plaus1$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_plaus1$money_mult2<-(us_stats_plaus1$curr_real+us_stats_plaus1$total_deposits)/(us_stats_plaus1$curr_real+us_stats_plaus1$total_reserves)

us_stats_plaus1_sum<- us_stats_plaus1 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))


mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                         i_beta_l =0.1,
                         i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = plaus_alts$i_sh_seller[2], i_seller_pp = plaus_alts$i_seller_pp[1], 
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0.90,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_plaus2<- bank_panel
us_stats_plaus2<-key_stats
us_stats_plaus2$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_plaus2$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_plaus2$money_mult2<-(us_stats_plaus2$curr_real+us_stats_plaus2$total_deposits)/(us_stats_plaus2$curr_real+us_stats_plaus2$total_reserves)

us_stats_plaus2_sum<- us_stats_plaus2 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))


mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                         i_beta_l =0.1,
                         i_num_banks = 100, i_sh_low_beta = 0, i_sh_seller = plaus_alts$i_sh_seller[3], i_seller_pp = plaus_alts$i_seller_pp[3], 
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0.90,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_plaus3<- bank_panel
us_stats_plaus3<-key_stats
us_stats_plaus3$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_plaus3$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_plaus3$money_mult2<-(us_stats_plaus3$curr_real+us_stats_plaus3$total_deposits)/(us_stats_plaus3$curr_real+us_stats_plaus3$total_reserves)

us_stats_plaus3_sum<- us_stats_plaus3 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))



###### Figure 1 c) ######


## Black and White

ggplot() + 
  geom_line(data = us_stats_plaus1_sum,  aes(x = date_m, y = med_mult, linetype = "2. Alternative 1"), size = 0.8)  +
  geom_line(data = us_stats_plaus2_sum,  aes(x = date_m, y = med_mult, linetype = "3. Alternative 2"), size = 0.8)  +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = med_mult, linetype = "1. Baseline"), size = 0.8) +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=14)) + theme(axis.text.x = element_text(size=14)) + theme(axis.text.y = element_text(size=14)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=14)) + guides(linetype = guide_legend(nrow = 2))+
  theme(legend.key.width = unit(3,"cm")) 


dev.copy(pdf,'alt_market_struct_bw.pdf')

dev.off()




##Colours

ggplot() + 
  #geom_line(data = us_stats_plaus3_sum,  aes(x = date_m, y = med_mult, color = "4. Alternative 3"))  +
  #geom_line(data = us_stats_plaus3_sum,  aes(x = date_m, y = bot_mult, color = "4. Alternative 3"), linetype="dashed")  +
  #geom_line(data = us_stats_plaus3_sum,  aes(x = date_m, y = top_mult, color = "4. Alternative 3"), linetype="dashed")  +
  geom_line(data = us_stats_plaus1_sum,  aes(x = date_m, y = med_mult, color = "2. Alternative 1"), size = 0.8)  +
  geom_line(data = us_stats_plaus1_sum,  aes(x = date_m, y = bot_mult, color = "2. Alternative 1"), linetype="dashed")  +
  geom_line(data = us_stats_plaus1_sum,  aes(x = date_m, y = top_mult, color = "2. Alternative 1"), linetype="dashed")  + 
  geom_line(data = us_stats_plaus2_sum,  aes(x = date_m, y = med_mult, color = "3. Alternative 2"), size = 0.8)  +
  geom_line(data = us_stats_plaus2_sum,  aes(x = date_m, y = bot_mult, color = "3. Alternative 2"), linetype="dashed")  +
  geom_line(data = us_stats_plaus2_sum,  aes(x = date_m, y = top_mult, color = "3. Alternative 2"), linetype="dashed")  + 
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = med_mult, color = "1. Baseline"), size = 0.8) +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = bot_mult, color = "1. Baseline"), linetype="dashed") +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = top_mult, color = "1. Baseline"), linetype="dashed") +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=14)) + theme(axis.text.x = element_text(size=14)) + theme(axis.text.y = element_text(size=14)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=14)) + guides(colour = guide_legend(nrow = 2))


dev.copy(pdf,'alt_market_struct.pdf')

dev.off()


##When reserves are more concentrated - there are banks in reserve excess earlier/for longer:


bank_push_plaus1_sum<- us_stats_plaus1 %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))




ggplot() + 
  #geom_line(data = bank_push_plaus3_sum,  aes(x = date_m, y = med_mult, color = "4. Alternative 3"))  +
  #geom_line(data = bank_push_plaus3_sum,  aes(x = date_m, y = bot_mult, color = "4. Alternative 3"), linetype="dashed")  +
  #geom_line(data = bank_push_plaus3_sum,  aes(x = date_m, y = top_mult, color = "4. Alternative 3"), linetype="dashed")  +
  geom_line(data = us_stats_plaus1_sum,  aes(x = date_m, y = med_push, color = "2. Alternative 1"), size = 0.8)  +
  geom_line(data = us_stats_plaus1_sum,  aes(x = date_m, y = bot_push, color = "2. Alternative 1"), linetype="dashed")  +
  geom_line(data = us_stats_plaus1_sum,  aes(x = date_m, y = top_push, color = "2. Alternative 1"), linetype="dashed")  + 
  geom_line(data = us_stats_plaus2_sum,  aes(x = date_m, y = med_push, color = "3. Alternative 2"), size = 0.8)  +
  geom_line(data = us_stats_plaus2_sum,  aes(x = date_m, y = bot_push, color = "3. Alternative 2"), linetype="dashed")  +
  geom_line(data = us_stats_plaus2_sum,  aes(x = date_m, y = top_push, color = "3. Alternative 2"), linetype="dashed")  + 
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = med_push, color = "1. Baseline"), size = 0.8) +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = bot_push, color = "1. Baseline"), linetype="dashed") +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = top_push, color = "1. Baseline"), linetype="dashed") +
  theme_bw() + ylab("") + xlab("") + theme(axis.text.x = element_text(size=14)) + theme(axis.text.y = element_text(size=14)) +  
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 200, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=250), fill="grey", alpha=0.2) 


dev.copy(pdf,'hp_market_struct.pdf')

dev.off()


################################## #################   SHARE NON-BANK SELLERS    ##################### ##################################


################################## Minor variation around baseline assumption


mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                         i_beta_l =0.1,
                         i_num_banks = 100, i_sh_low_beta = 0,  i_sh_seller = 0.8,i_seller_pp = 0.6,  
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0.8,
                         i_repay = 0.01, i_print_detail = FALSE)



us_panel_less_nb<- bank_panel
us_statsless_nb<-key_stats
us_statsless_nb$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_statsless_nb$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_statsless_nb$money_mult2<-(us_statsless_nb$curr_real+us_statsless_nb$total_deposits)/(us_statsless_nb$curr_real+us_statsless_nb$total_reserves)


us_statsless_nb_sum<- us_statsless_nb %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))




mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                         i_beta_l =0.1,
                         i_num_banks = 100, i_sh_low_beta = 0,  i_sh_seller = 0.8,i_seller_pp = 0.6,  
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 1,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_all_nb<- bank_panel
us_stats_all_nb<-key_stats
us_stats_all_nb$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_all_nb$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_all_nb$money_mult2<-(us_stats_all_nb$curr_real+us_stats_all_nb$total_deposits)/(us_stats_all_nb$curr_real+us_stats_all_nb$total_reserves)


us_stats_all_nb_sum<- us_stats_all_nb %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))


################################## Effect of extremes



mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                         i_beta_l =0.1,
                         i_num_banks = 100, i_sh_low_beta = 0,  i_sh_seller = 0.8,i_seller_pp = 0.6,  
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_no_nb<- bank_panel
us_stats_no_nb<-key_stats
us_stats_no_nb$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_no_nb$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_no_nb$money_mult2<-(us_stats_no_nb$curr_real+us_stats_no_nb$total_deposits)/(us_stats_no_nb$curr_real+us_stats_no_nb$total_reserves)


us_stats_no_nb_sum<- us_stats_no_nb %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))


##### Figure 2 a) ######

##Black and white

ggplot()+   geom_line(data = us_stats_all_nb_sum, aes(x = date_m, y = med_mult, linetype = "3. All non-bank"), size = 1.2) +
  geom_line(data = us_stats_no_nb_sum, aes(x = date_m, y = med_mult, linetype = "4. No non-bank"), size = 1.2) +
  geom_line(data = us_statsless_nb_sum, aes(x = date_m, y = med_mult, linetype = "2. 80% non-bank"), size = 1.2) +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = med_mult, linetype = "1. Baseline"), size = 1.2) +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=14)) + theme(axis.text.x = element_text(size=14)) + theme(axis.text.y = element_text(size=14)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=14)) + 
  guides(linetype = guide_legend(nrow = 2))+
  theme(legend.key.width = unit(3,"cm")) 


dev.copy(pdf,'share_nb_bw.pdf')

dev.off()


##Colours

ggplot()+   geom_line(data = us_stats_all_nb_sum, aes(x = date_m, y = med_mult, color = "3. All non-bank"), size = 0.8) +
  geom_line(data = us_stats_all_nb_sum, aes(x = date_m, y = bot_mult, color = "3. All non-bank"), linetype="dashed") +
  geom_line(data = us_stats_all_nb_sum, aes(x = date_m, y = top_mult, color = "3. All non-bank"), linetype="dashed") +
  geom_line(data = us_stats_no_nb_sum, aes(x = date_m, y = med_mult, color = "4. No non-bank"), size = 0.8) +
  geom_line(data = us_stats_no_nb_sum, aes(x = date_m, y = bot_mult, color = "4. No non-bank"), linetype="dashed") +
  geom_line(data = us_stats_no_nb_sum, aes(x = date_m, y = top_mult, color = "4. No non-bank"), linetype="dashed") +
  geom_line(data = us_statsless_nb_sum, aes(x = date_m, y = med_mult, color = "2. 80% non-bank"), size = 0.8) +
  geom_line(data = us_statsless_nb_sum, aes(x = date_m, y = bot_mult, color = "2. 80% non-bank"), linetype="dashed") +
  geom_line(data = us_statsless_nb_sum, aes(x = date_m, y = top_mult, color = "2. 80% non-bank"), linetype="dashed") +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = med_mult, color = "1. Baseline"), size = 0.8) +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = bot_mult, color = "1. Baseline"), linetype="dashed") +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = top_mult, color = "1. Baseline"), linetype="dashed") +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=14)) + theme(axis.text.x = element_text(size=14)) + theme(axis.text.y = element_text(size=14)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=14)) + guides(colour = guide_legend(nrow = 2))


dev.copy(pdf,'share_nb.pdf')

dev.off()


################################## ######################   NUMBER OF BANKS   ########################## ##################################



mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                         i_beta_l =0.1,
                         i_num_banks = 50, i_sh_low_beta = 0, i_sh_seller = 0.8, i_seller_pp = 0.6, 
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0.90,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_50bank<- bank_panel
us_stats_50bank<-key_stats
us_stats_50bank$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_50bank$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_50bank$money_mult2<-(us_stats_50bank$curr_real+us_stats_50bank$total_deposits)/(us_stats_50bank$curr_real+us_stats_50bank$total_reserves)


us_stats_50bank_sum<- us_stats_50bank %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                         i_beta_l =0.1,
                         i_num_banks = 200, i_sh_low_beta = 0, i_sh_seller = 0.8, i_seller_pp = 0.6, 
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0.90,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_200bank<- bank_panel
us_stats_200bank<-key_stats
us_stats_200bank$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_200bank$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_200bank$money_mult2<-(us_stats_200bank$curr_real+us_stats_200bank$total_deposits)/(us_stats_200bank$curr_real+us_stats_200bank$total_reserves)


us_stats_200bank_sum<- us_stats_200bank %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))

mm_model_core_new_iterations(num_it = 100, i_cb = us_mon_agg2$base_ch, i_beta_h = 0.85, 
                         i_beta_l =0.1,
                         i_num_banks = 400, i_sh_low_beta = 0, i_sh_seller = 0.8, i_seller_pp = 0.6, 
                         i_res_start = us_mon_agg2$RESERVES[1], i_dep_start = us_mon_agg2$m2_fix[1], 
                         i_curr_res= us_mon_agg2$cr,
                         i_non_bank_sh = 0.90,
                         i_repay = 0.01, i_print_detail = FALSE)


us_stats_panel_400bank<- bank_panel
us_stats_400bank<-key_stats
us_stats_400bank$date_m<-c(us_mon_agg2$date_m[1],us_mon_agg2$date_m)
us_stats_400bank$curr_real<-c(us_mon_agg2$CURRENCY[1],us_mon_agg2$CURRENCY)
us_stats_400bank$money_mult2<-(us_stats_400bank$curr_real+us_stats_400bank$total_deposits)/(us_stats_400bank$curr_real+us_stats_400bank$total_reserves)


us_stats_400bank_sum<- us_stats_400bank %>%
  group_by(date_m) %>%
  summarize(med_mult = quantile(money_mult2, prob = 0.5), 
            bot_mult = quantile(money_mult2, prob = 0.01), 
            top_mult = quantile(money_mult2, prob = 0.99),
            med_loan = quantile(total_loans, prob = 0.5), 
            bot_loan = quantile(total_loans, prob = 0.01), 
            top_loan = quantile(total_loans, prob = 0.99),
            med_push = quantile(bank_push, prob = 0.5), 
            bot_push = quantile(bank_push, prob = 0.01), 
            top_push = quantile(bank_push, prob = 0.99),
            med_dep = quantile(total_deposits, prob = 0.5), 
            bot_dep = quantile(total_deposits, prob = 0.01), 
            top_dep = quantile(total_deposits, prob = 0.99))



##### Figure 2b) #####

### Black and white


ggplot()+   geom_line(data = us_stats_50bank_sum, aes(x = date_m, y = med_mult, linetype = "50 banks"), size = 0.8) +
   geom_line(data = us_stats_200bank_sum, aes(x = date_m, y = med_mult, linetype = "200 banks"), size = 0.8) +
  geom_line(data = us_stats_400bank_sum, aes(x = date_m, y = med_mult, linetype = "400 banks"), size = 0.8) +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = med_mult, linetype = "100 banks (baseline)"), size = 0.8) +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=14)) + theme(axis.text.x = element_text(size=14)) + theme(axis.text.y = element_text(size=14)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") +
  theme(legend.text=element_text(size=14)) + guides(linetype = guide_legend(nrow = 2))+
  theme(legend.key.width = unit(3,"cm"))

dev.copy(pdf,'num_banks_bw.pdf')

dev.off()




### Colours

ggplot()+   geom_line(data = us_stats_50bank_sum, aes(x = date_m, y = med_mult, color = "50 banks"), size = 0.8) +
  geom_line(data = us_stats_50bank_sum, aes(x = date_m, y = bot_mult, color = "50 banks"), linetype="dashed") +
  geom_line(data = us_stats_50bank_sum, aes(x = date_m, y = top_mult, color = "50 banks"), linetype="dashed") +
  geom_line(data = us_stats_200bank_sum, aes(x = date_m, y = med_mult, color = "200 banks"), size = 0.8) +
  geom_line(data = us_stats_200bank_sum, aes(x = date_m, y = bot_mult, color = "200 banks"), linetype="dashed") +
  geom_line(data = us_stats_200bank_sum, aes(x = date_m, y = top_mult, color = "200 banks"), linetype="dashed") +
  geom_line(data = us_stats_400bank_sum, aes(x = date_m, y = med_mult, color = "400 banks"), size = 0.8) +
  geom_line(data = us_stats_400bank_sum, aes(x = date_m, y = bot_mult, color = "400 banks"), linetype="dashed") +
  geom_line(data = us_stats_400bank_sum, aes(x = date_m, y = top_mult, color = "400 banks"), linetype="dashed") +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = med_mult, color = "100 banks (baseline)"), size = 0.8) +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = bot_mult, color = "100 banks (baseline)"), linetype="dashed") +
  geom_line(data = us_stats_85_sum, aes(x = date_m, y = top_mult, color = "100 banks (baseline)"), linetype="dashed") +
  theme_bw() + ylab("") + xlab("") + 
  scale_y_continuous(breaks=seq(2,8,1), limits = c(2,8.2)) +
  scale_x_date(breaks = as.Date(c("2008-01-01", "2010-01-01", "2012-01-01", "2014-01-01", "2016-01-01", "2018-01-01", "2020-01-01")), labels = c("2008", "2010", "2012", "2014", "2016", "2018", "2020")) +
  geom_text(data=lsap_dates, mapping=aes(x=end, y= 6.5, label=prog), size=4, angle=90, vjust=-0.4, hjust=0, color = "blue") +
  geom_rect(data=lsap_dates, mapping=aes(xmin=start, xmax=end, ymin=2, ymax=8.2), fill="grey", alpha=0.2) +
  scale_color_brewer(palette = "Set1") + scale_fill_brewer(palette = "Set1") + theme_bw()+
  theme(text = element_text(size=14)) + theme(axis.text.x = element_text(size=14)) + theme(axis.text.y = element_text(size=14)) +
  theme(legend.title = element_blank()) + theme(legend.position="bottom") + theme(legend.text=element_text(size=14)) + guides(colour = guide_legend(nrow = 2))



dev.copy(pdf,'num_banks.pdf')

dev.off()

